# -*- coding: utf-8 -*-
from django.conf import settings
from django.contrib.auth.models import User
from django.test import TestCase

from cms import api
from cms.models import CMSPlugin
from cms.test_utils.testcases import BaseCMSTestCase, URL_CMS_PLUGIN_ADD
from cms.utils import get_cms_setting

from .cms_plugins import AnimationPlugin, WOWAnimationPlugin


class AnimatePluginTestCase(TestCase, BaseCMSTestCase):
    su_username = 'user'
    su_password = 'pass'

    def setUp(self):
        self.template = get_cms_setting('TEMPLATES')[0][0]
        self.language = settings.LANGUAGES[0][0]
        self.page = api.create_page(
            'page',
            self.template,
            self.language,
            published=True
        )
        self.placeholder = self.page.placeholders.all()[0]
        self.superuser = self.create_superuser()

    def create_superuser(self):
        return User.objects.create_superuser(
            self.su_username,
            'email@example.com',
            self.su_password
        )

    def test_animation_not_infinite(self):
        self.client.login(username=self.su_username, password=self.su_password)

        plugin = api.add_plugin(
            self.placeholder,
            AnimationPlugin,
            self.language,
            animation_class='shake',
            infinite=False,
        )
        self.page.publish(self.language)
        url = self.page.get_absolute_url()
        response = self.client.get(url)

        self.assertContains(response, 'animate.css')
        self.assertContains(response, 'shake')
        self.assertNotContains(response, 'infinite')
        self.assertEqual(plugin.__str__(), 'Animate shake')
        self.page.delete()


    def test_animation_infinite(self):
        self.client.login(username=self.su_username, password=self.su_password)

        plugin = api.add_plugin(
            self.placeholder,
            AnimationPlugin,
            self.language,
            animation_class='wobble',
            infinite=True,
        )
        self.page.publish(self.language)
        url = self.page.get_absolute_url()
        response = self.client.get(url)

        self.assertContains(response, 'animate')
        self.assertContains(response, 'wobble')
        self.assertContains(response, 'infinite')


    def test_wow_animation_no_additional_arguments(self):
        self.client.login(username=self.su_username, password=self.su_password)

        plugin = api.add_plugin(
            self.placeholder,
            WOWAnimationPlugin,
            self.language,
            animation_class='flash',
        )
        self.page.publish(self.language)
        url = self.page.get_absolute_url()
        response = self.client.get(url)

        self.assertContains(response, 'wow')
        self.assertNotContains(response, 'duration')
        self.assertNotContains(response, 'delay')
        self.assertNotContains(response, 'offset')
        self.assertNotContains(response, 'iteration')


    def test_wow_animation_all_arguments(self):
        self.client.login(username=self.su_username, password=self.su_password)

        plugin = api.add_plugin(
            self.placeholder,
            WOWAnimationPlugin,
            self.language,
            animation_class='hinge',
            duration=1,
            delay=2,
            offset=3,
            iteration=4,
        )
        self.page.publish(self.language)
        url = self.page.get_absolute_url()
        response = self.client.get(url)

        self.assertContains(response, 'wow.js')
        self.assertContains(response, 'hinge')
        self.assertContains(response, 'data-wow-duration="1s"')
        self.assertContains(response, 'data-wow-delay="2s"')
        self.assertContains(response, 'data-wow-offset="3"')
        self.assertContains(response, 'data-wow-iteration="4"')



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

ANIMATION_CHOICES = (
    ('bounce', _('Bounce')),
    ('flash', _('Flash')),
    ('pulse', _('Pulse')),
    ('rubberBand', _('Rubber Band')),
    ('shake', _('Shake')),
    ('swing', _('Swing')),
    ('tada', _('Ta-Da')),
    ('wobble', _('Wobble')),
    ('bounceIn', _('Bounce In')),
    ('bounceInDown', _('Bounce In Down')),
    ('bounceInLeft', _('Bounce In Left')),
    ('bounceInRight', _('Bounce In Right')),
    ('bounceInUp', _('Bounce In Up')),
    ('bounceOut', _('Bounce Out')),
    ('bounceOutDown', _('Bounce Out Down')),
    ('bounceOutLeft', _('Bounce Out Left')),
    ('bounceOutRight', _('Bounce Out Right')),
    ('bounceOutUp', _('Bounce Out Up')),
    ('fadeIn', _('Fade In')),
    ('fadeInDown', _('Fade In Down')),
    ('fadeInDownBig', _('Fade In Down Big')),
    ('fadeInLeft', _('Fade In Left')),
    ('fadeInLeftBig', _('Fade In Left Big')),
    ('fadeInRight', _('Fade In Right')),
    ('fadeInRightBig', _('Fade In Right Big')),
    ('fadeInUp', _('Fade In Up')),
    ('fadeInUpBig', _('Fade In Up Big')),
    ('fadeOut', _('Fade Out')),
    ('fadeOutDown', _('Fade Out Down')),
    ('fadeOutDownBig', _('Fade Out Down Big')),
    ('fadeOutLeft', _('Fade Out Left')),
    ('fadeOutLeftBig', _('Fade Out Left Big')),
    ('fadeOutRight', _('Fade Out Right')),
    ('fadeOutRightBig', _('Fade Out Right Big')),
    ('fadeOutUp', _('Fade Out Up')),
    ('fadeOutUpBig', _('Fade Out Up Big')),
    ('flipInX', _('Flip In X')),
    ('flipInY', _('Flip In Y')),
    ('flipOutX', _('Flip Out X')),
    ('flipOutY', _('Flip Out Y')),
    ('lightSpeedIn', _('Light Speed In')),
    ('lightSpeedOut', _('Light Speed Out')),
    ('rotateIn', _('Rotate In')),
    ('rotateInDownLeft', _('Rotate In Down Left')),
    ('rotateInDownRight', _('Rotate In Down Right')),
    ('rotateInUpLeft', _('Rotate In Up Left')),
    ('rotateInUpRight', _('Rotate In Up Right')),
    ('rotateOut', _('Rotate Out')),
    ('rotateOutDownLeft', _('Rotate Out Down Left')),
    ('rotateOutDownRight', _('Rotate Out Down Right')),
    ('rotateOutUpLeft', _('Rotate Out Up Left')),
    ('rotateOutUpRight', _('Rotate Out Up Right')),
    ('hinge', _('Hinge')),
    ('rollIn', _('Roll In')),
    ('rollOut', _('Roll Out')),
    ('zoomIn', _('Zoom In')),
    ('zoomInDown', _('Zoom Out')),
    ('zoomInLeft', _('Zoom In Left')),
    ('zoomInRight', _('Zoom In Right')),
    ('zoomInUp', _('Zoom In Up')),
    ('zoomOut', _('Zoom Out')),
    ('zoomOutDown', _('Zoom Out Down')),
    ('zoomOutLeft', _('Zoom Out Left')),
    ('zoomOutRight', _('Zoom Out Right')),
    ('zoomOutUp', _('Zoom Out Up')),
    ('slideInDown', _('Slide In Down')),
    ('slideInLeft', _('Slide In Left')),
    ('slideInRight', _('Slide In Right')),
    ('slideInUp', _('Slide In Up')),
    ('slideOutDown', _('Slide Out Down')),
    ('slideOutLeft', _('Slide Out Left')),
    ('slideOutRight', _('Slide Out Right')),
    ('slideOutUp', _('Slide Out Up')),
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='Animation',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('animation_class', models.CharField(default=b'bounce', max_length=25, choices=[(b'bounce', 'Bounce'), (b'flash', 'Flash'), (b'pulse', 'Pulse'), (b'rubberBand', 'Rubber Band'), (b'shake', 'Shake'), (b'swing', 'Swing'), (b'tada', 'Ta-Da'), (b'wobble', 'Wobble'), (b'bounceIn', 'Bounce In'), (b'bounceInDown', 'Bounce In Down'), (b'bounceInLeft', 'Bounce In Left'), (b'bounceInRight', 'Bounce In Right'), (b'bounceInUp', 'Bounce In Up'), (b'bounceOut', 'Bounce Out'), (b'bounceOutDown', 'Bounce Out Down'), (b'bounceOutLeft', 'Bounce Out Left'), (b'bounceOutRight', 'Bounce Out Right'), (b'bounceOutUp', 'Bounce Out Up'), (b'fadeIn', 'Fade In'), (b'fadeInDown', 'Fade In Down'), (b'fadeInDownBig', 'Fade In Down Big'), (b'fadeInLeft', 'Fade In Left'), (b'fadeInLeftBig', 'Fade In Left Big'), (b'fadeInRight', 'Fade In Right'), (b'fadeInRightBig', 'Fade In Right Big'), (b'fadeInUp', 'Fade In Up'), (b'fadeInUpBig', 'Fade In Up Big'), (b'fadeOut', 'Fade Out'), (b'fadeOutDown', 'Fade Out Down'), (b'fadeOutDownBig', 'Fade Out Down Big'), (b'fadeOutLeft', 'Fade Out Left'), (b'fadeOutLeftBig', 'Fade Out Left Big'), (b'fadeOutRight', 'Fade Out Right'), (b'fadeOutRightBig', 'Fade Out Right Big'), (b'fadeOutUp', 'Fade Out Up'), (b'fadeOutUpBig', 'Fade Out Up Big'), (b'flipInX', 'Flip In X'), (b'flipInY', 'Flip In Y'), (b'flipOutX', 'Flip Out X'), (b'flipOutY', 'Flip Out Y'), (b'lightSpeedIn', 'Light Speed In'), (b'lightSpeedOut', 'Light Speed Out'), (b'rotateIn', 'Rotate In'), (b'rotateInDownLeft', 'Rotate In Down Left'), (b'rotateInDownRight', 'Rotate In Down Right'), (b'rotateInUpLeft', 'Rotate In Up Left'), (b'rotateInUpRight', 'Rotate In Up Right'), (b'rotateOut', 'Rotate Out'), (b'rotateOutDownLeft', 'Rotate Out Down Left'), (b'rotateOutDownRight', 'Rotate Out Down Right'), (b'rotateOutUpLeft', 'Rotate Out Up Left'), (b'rotateOutUpRight', 'Rotate Out Up Right'), (b'hinge', 'Hinge'), (b'rollIn', 'Roll In'), (b'rollOut', 'Roll Out'), (b'zoomIn', 'Zoom In'), (b'zoomInDown', 'Zoom Out'), (b'zoomInLeft', 'Zoom In Left'), (b'zoomInRight', 'Zoom In Right'), (b'zoomInUp', 'Zoom In Up'), (b'zoomOut', 'Zoom Out'), (b'zoomOutDown', 'Zoom Out Down'), (b'zoomOutLeft', 'Zoom Out Left'), (b'zoomOutRight', 'Zoom Out Right'), (b'zoomOutUp', 'Zoom Out Up'), (b'slideInDown', 'Slide In Down'), (b'slideInLeft', 'Slide In Left'), (b'slideInRight', 'Slide In Right'), (b'slideInUp', 'Slide In Up'), (b'slideOutDown', 'Slide Out Down'), (b'slideOutLeft', 'Slide Out Left'), (b'slideOutRight', 'Slide Out Right'), (b'slideOutUp', 'Slide Out Up')])),
                ('infinite', models.NullBooleanField(help_text='Infinite Loop')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='WOWAnimation',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('animation_class', models.CharField(default=b'bounce', max_length=25, choices=[(b'bounce', 'Bounce'), (b'flash', 'Flash'), (b'pulse', 'Pulse'), (b'rubberBand', 'Rubber Band'), (b'shake', 'Shake'), (b'swing', 'Swing'), (b'tada', 'Ta-Da'), (b'wobble', 'Wobble'), (b'bounceIn', 'Bounce In'), (b'bounceInDown', 'Bounce In Down'), (b'bounceInLeft', 'Bounce In Left'), (b'bounceInRight', 'Bounce In Right'), (b'bounceInUp', 'Bounce In Up'), (b'bounceOut', 'Bounce Out'), (b'bounceOutDown', 'Bounce Out Down'), (b'bounceOutLeft', 'Bounce Out Left'), (b'bounceOutRight', 'Bounce Out Right'), (b'bounceOutUp', 'Bounce Out Up'), (b'fadeIn', 'Fade In'), (b'fadeInDown', 'Fade In Down'), (b'fadeInDownBig', 'Fade In Down Big'), (b'fadeInLeft', 'Fade In Left'), (b'fadeInLeftBig', 'Fade In Left Big'), (b'fadeInRight', 'Fade In Right'), (b'fadeInRightBig', 'Fade In Right Big'), (b'fadeInUp', 'Fade In Up'), (b'fadeInUpBig', 'Fade In Up Big'), (b'fadeOut', 'Fade Out'), (b'fadeOutDown', 'Fade Out Down'), (b'fadeOutDownBig', 'Fade Out Down Big'), (b'fadeOutLeft', 'Fade Out Left'), (b'fadeOutLeftBig', 'Fade Out Left Big'), (b'fadeOutRight', 'Fade Out Right'), (b'fadeOutRightBig', 'Fade Out Right Big'), (b'fadeOutUp', 'Fade Out Up'), (b'fadeOutUpBig', 'Fade Out Up Big'), (b'flipInX', 'Flip In X'), (b'flipInY', 'Flip In Y'), (b'flipOutX', 'Flip Out X'), (b'flipOutY', 'Flip Out Y'), (b'lightSpeedIn', 'Light Speed In'), (b'lightSpeedOut', 'Light Speed Out'), (b'rotateIn', 'Rotate In'), (b'rotateInDownLeft', 'Rotate In Down Left'), (b'rotateInDownRight', 'Rotate In Down Right'), (b'rotateInUpLeft', 'Rotate In Up Left'), (b'rotateInUpRight', 'Rotate In Up Right'), (b'rotateOut', 'Rotate Out'), (b'rotateOutDownLeft', 'Rotate Out Down Left'), (b'rotateOutDownRight', 'Rotate Out Down Right'), (b'rotateOutUpLeft', 'Rotate Out Up Left'), (b'rotateOutUpRight', 'Rotate Out Up Right'), (b'hinge', 'Hinge'), (b'rollIn', 'Roll In'), (b'rollOut', 'Roll Out'), (b'zoomIn', 'Zoom In'), (b'zoomInDown', 'Zoom Out'), (b'zoomInLeft', 'Zoom In Left'), (b'zoomInRight', 'Zoom In Right'), (b'zoomInUp', 'Zoom In Up'), (b'zoomOut', 'Zoom Out'), (b'zoomOutDown', 'Zoom Out Down'), (b'zoomOutLeft', 'Zoom Out Left'), (b'zoomOutRight', 'Zoom Out Right'), (b'zoomOutUp', 'Zoom Out Up'), (b'slideInDown', 'Slide In Down'), (b'slideInLeft', 'Slide In Left'), (b'slideInRight', 'Slide In Right'), (b'slideInUp', 'Slide In Up'), (b'slideOutDown', 'Slide Out Down'), (b'slideOutLeft', 'Slide Out Left'), (b'slideOutRight', 'Slide Out Right'), (b'slideOutUp', 'Slide Out Up')])),
                ('duration', models.PositiveSmallIntegerField(help_text='Change the animation duration', null=True, blank=True)),
                ('delay', models.PositiveSmallIntegerField(help_text='Delay before the animation starts', null=True, blank=True)),
                ('offset', models.PositiveSmallIntegerField(help_text='Distance to start the animation (related to the browser bottom)', null=True, blank=True)),
                ('iteration', models.PositiveSmallIntegerField(help_text='Number of times the animation is repeated', null=True, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Animation'
        db.create_table(u'aldryn_wow_animation', (
            (u'cmsplugin_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['cms.CMSPlugin'], unique=True, primary_key=True)),
            ('animation_class', self.gf('django.db.models.fields.CharField')(default='bounce', max_length=25)),
            ('infinite', self.gf('django.db.models.fields.NullBooleanField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'aldryn_wow', ['Animation'])

        # Adding model 'WOWAnimation'
        db.create_table(u'aldryn_wow_wowanimation', (
            (u'cmsplugin_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['cms.CMSPlugin'], unique=True, primary_key=True)),
            ('animation_class', self.gf('django.db.models.fields.CharField')(default='bounce', max_length=25)),
            ('duration', self.gf('django.db.models.fields.PositiveSmallIntegerField')(null=True, blank=True)),
            ('delay', self.gf('django.db.models.fields.PositiveSmallIntegerField')(null=True, blank=True)),
            ('offset', self.gf('django.db.models.fields.PositiveSmallIntegerField')(null=True, blank=True)),
            ('iteration', self.gf('django.db.models.fields.PositiveSmallIntegerField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'aldryn_wow', ['WOWAnimation'])


    def backwards(self, orm):
        # Deleting model 'Animation'
        db.delete_table(u'aldryn_wow_animation')

        # Deleting model 'WOWAnimation'
        db.delete_table(u'aldryn_wow_wowanimation')


    models = {
        u'aldryn_wow.animation': {
            'Meta': {'object_name': 'Animation', '_ormbases': ['cms.CMSPlugin']},
            'animation_class': ('django.db.models.fields.CharField', [], {'default': "'bounce'", 'max_length': '25'}),
            u'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'infinite': ('django.db.models.fields.NullBooleanField', [], {'null': 'True', 'blank': 'True'})
        },
        u'aldryn_wow.wowanimation': {
            'Meta': {'object_name': 'WOWAnimation', '_ormbases': ['cms.CMSPlugin']},
            'animation_class': ('django.db.models.fields.CharField', [], {'default': "'bounce'", 'max_length': '25'}),
            u'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'delay': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'duration': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'iteration': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'offset': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        'cms.cmsplugin': {
            'Meta': {'object_name': 'CMSPlugin'},
            'changed_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.CMSPlugin']", 'null': 'True', 'blank': 'True'}),
            'placeholder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'plugin_type': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'position': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'})
        }
    }

    complete_apps = ['aldryn_wow']


# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible

from cms.models.pluginmodel import CMSPlugin

from .utils import ANIMATION_CHOICES


@python_2_unicode_compatible
class Animation(CMSPlugin):
    animation_class = models.CharField(
        max_length=25,
        choices=ANIMATION_CHOICES,
        default=ANIMATION_CHOICES[0][0],
        blank=False,
    )
    infinite = models.NullBooleanField(
        help_text=_('Infinite Loop'),
    )

    def __str__(self):
        return ''.join(('Animate ', self.animation_class))


@python_2_unicode_compatible
class WOWAnimation(CMSPlugin):
    animation_class = models.CharField(
        max_length=25,
        choices=ANIMATION_CHOICES,
        default=ANIMATION_CHOICES[0][0],
        blank=False,
    )
    duration = models.PositiveSmallIntegerField(
        help_text=_('Change the animation duration'),
        blank=True,
        null=True
    )
    delay = models.PositiveSmallIntegerField(
        help_text=_('Delay before the animation starts'),
        blank=True,
        null=True,
    )
    offset = models.PositiveSmallIntegerField(
        help_text=_(
            'Distance to start the animation '
            '(related to the browser bottom)'
        ),
        blank=True,
        null=True,
    )
    iteration = models.PositiveSmallIntegerField(
        help_text=_('Number of times the animation is repeated'),
        blank=True,
        null=True,
    )

    def __str__(self):
        return ''.join(('WOW ', self.animation_class))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup
from aldryn_wow import __version__


INSTALL_REQUIRES = [
    'django-cms>=3.0',
]

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Communications',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Message Boards',
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3.3",
    "Programming Language :: Python :: 3.4",
]

setup(
    name='aldryn-wow',
    version=__version__,
    description='Plugin for aldryn to include awesome animations from WOW.js and Animate.css',
    author='Aditya Narayan',
    author_email='narayanaditya95@gmail.com',
    url='https://github.com/narayanaditya95/aldryn-wow',
    packages=['aldryn_wow', 'aldryn_wow.migrations', 'aldryn_wow.south_migrations'],
    install_requires=INSTALL_REQUIRES,
    license='LICENSE',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    long_description=open('README.rst').read() + open('CHANGELOG.rst').read(),
    include_package_data=True,
    zip_safe=False,
    test_suite='test_settings.run',
)



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import models


class AnimationPlugin(CMSPluginBase):
    model = models.Animation
    name = _('Animation')
    render_template = 'aldryn_wow/animation.html'
    allow_children = True
    cache = True

    def render(self, context, instance, placeholder):
        context.update({'instance': instance})
        return context


plugin_pool.register_plugin(AnimationPlugin)


class WOWAnimationPlugin(CMSPluginBase):
    model = models.WOWAnimation
    name = _("Wow Animation")
    render_template = 'aldryn_wow/wow_animation.html'
    allow_children = True
    cache = True

    def render(self, context, instance, placeholder):
        context.update({'instance': instance})
        return context


plugin_pool.register_plugin(WOWAnimationPlugin)
